/*
 * Programming in Java, Jacobs University, 2015
 *
 * This class demonstrates how to use thread pools via the
 * ExecutorService. Thread pools are an efficient way to execute
 * many concurrent activities while controlling the number of
 * active threads.
 *
 * $ java B a b c d e f g h i j
 */

import java.lang.Runnable;
import java.lang.Thread;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class B implements Runnable
{
    private String s = null;
    private int ms = 0;

    public B(String s)
    {
	this(s, 1000);
    }

    public B(String s, int ms)
    {
	this.s = s;
	this.ms = ms;
    }

    public void run() 
    {
	try {
	    TimeUnit.MILLISECONDS.sleep(ms);
	} catch(InterruptedException e) {
	    Thread.currentThread().interrupt();
	}
	System.out.print(s + " ");
    }

    public static void main(String[] args)
	throws InterruptedException
    {
	ExecutorService pool = Executors.newFixedThreadPool(3);
	for (String arg: args) {
            pool.execute(new B(arg, 123));
	}
	
        pool.shutdown();
        while (! pool.awaitTermination(4242, TimeUnit.MILLISECONDS)) {
	    System.err.println("timeout while waiting for termination: retrying...");
        }
	if (args.length > 0) {
	    System.out.println();
	}
    }
}
